@@ -41,7 +41,9 @@ impl ParsedExternFn {
 
                 let maybe_return_ty = self.maybe_async_rust_fn_return_ty(swift_bridge_path, types);
 
-                if self.sig.asyncness.is_none() {
+                let is_async = self.sig.asyncness.is_some();
+
+                if !is_async {
                     quote! {
                         #[export_name = #link_name]
                         pub extern "C" fn #prefixed_fn_name ( #params ) #ret {
@@ -49,10 +51,16 @@ impl ParsedExternFn {
                         }
                     }
                 } else {
-                    let (call_fn, call_callback) = if maybe_return_ty.is_some() {
+                    let (await_fut, call_callback) = if maybe_return_ty.is_some() {
+                        let return_ty = self.return_ty_built_in(types).unwrap();
+                        let awaited_val = return_ty.convert_rust_value_to_ffi_compatible_value(
+                            &quote! {fut.await},
+                            swift_bridge_path,
+                        );
+
                         (
                             quote! {
-                                let val = #call_fn;
+                                let val = #awaited_val;
                             },
                             quote! {
                                 (callback)(callback_wrapper, val)
@@ -61,7 +69,7 @@ impl ParsedExternFn {
                     } else {
                         (
                             quote! {
-                                #call_fn;
+                                fut.await;
                             },
                             quote! {
                                 (callback)(callback_wrapper)
@@ -73,11 +81,13 @@ impl ParsedExternFn {
                         #[export_name = #link_name]
                         pub extern "C" fn #prefixed_fn_name (
                             callback_wrapper: *mut std::ffi::c_void,
-                            callback: extern "C" fn(*mut std::ffi::c_void #maybe_return_ty) -> ()
+                            callback: extern "C" fn(*mut std::ffi::c_void #maybe_return_ty) -> (),
+                            #params
                         ) {
                             let callback_wrapper = swift_bridge::async_support::SwiftCallbackWrapper(callback_wrapper);
+                            let fut = #call_fn;
                             let task = async move {
-                                #call_fn
+                                #await_fut
 
                                 let callback_wrapper = callback_wrapper;
                                 let callback_wrapper = callback_wrapper.0;
@@ -114,14 +124,9 @@ impl ParsedExternFn {
 
         let call_args = self.to_call_rust_args(swift_bridge_path, types);
 
-        let mut call_fn = quote! {
+        let call_fn = quote! {
             #fn_name ( #call_args )
         };
-        if self.sig.asyncness.is_some() {
-            call_fn = quote! {
-                #call_fn.await
-            };
-        }
 
         let mut call_fn = if self.is_method() {
             self.call_method_tokens(&call_fn)
@@ -141,7 +146,11 @@ impl ParsedExternFn {
             }
         }
 
-        call_fn = return_ty.convert_rust_value_to_ffi_compatible_value(&call_fn, swift_bridge_path);
+        // Async functions get this conversion done after awaiting the returned future.
+        if self.sig.asyncness.is_none() {
+            call_fn =
+                return_ty.convert_rust_value_to_ffi_compatible_value(&call_fn, swift_bridge_path);
+        }
 
         call_fn
     }
@@ -175,7 +184,7 @@ impl ParsedExternFn {
                     todo!()
                 }
                 TypeDeclaration::Opaque(ty) => {
-                    let ty = &ty.ident;
+                    let ty = &ty.ty;
                     quote! {#ty::}
                 }
             }
